unit SystemInfo;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls, StdCtrls,Registry;

type string1 = string[1];
type string30 = string[30];

type
  TSystemInfo = class(TComponent)
  private
    FArchitecture       :string;
    FProcessorType      :string;
    FNumberOfProcessors :Integer;
    FTotalPhysMemory    :longint;
    FAvailPhysMemory    :longint;
    FTotalSwapMemory    :longint;
    FAvailSwapMemory    :longint;
    FRegUserName        :string;
    FRegCompanyName     :string;
    FComputerName       :string;
    FNetworkUserName    :string;
    FSystemDirectory    :string;
    FTempDirectory      :string;
    FWindowsDirectory   :string;
    FMajorVersion       :string;
    FMinorVersion       :string;
    FBuildNumber        :string;
    FPlatform           :string;
    function GetTotalPhysMemory:longint;
    function GetAvailPhysMemory:longint;
    function GetTotalSwapMemory:longint;
    function GetAvailSwapMemory:longint;
    function GetComputernm:string;
    function GetUsernm:string;
    function GetSystemDir:string;
    function GetWindowsDir:string;
    function GetTempDir:string;
  protected
    { Protected declarations }
  public
    constructor create(AOwner:TComponent); override;
  published
    { Published declarations }
    property NumberOfProcessors :Integer read FNumberOfProcessors;
    property Architecture :string read FArchitecture;
    property ProcessorType :string read fProcessorType;
    property TotalPhysMemory :longint read GetTotalPhysMemory;
    property AvailPhysMemory :longint read GetAvailPhysMemory;
    property TotalSwapMemory :longint read GetTotalSwapMemory;
    property AvailSwapMemory :longint read GetAvailSwapMemory;
    property RegUserName :string read fregusername;
    property RegCompanyName :string read fregcompanyname;
    property ComputerName :string read getcomputernm;
    property NetworkUserName :string read getusernm;
    property SystemDirectory :string read getsystemdir;
    property WindowsDirectory :string read getwindowsdir;
    property TempDirectory :string read gettempdir;
    property MajorVersion :string read fmajorversion;
    property MinorVersion :string read fminorversion;
    property BuildNumber :string read fbuildnumber;
    property Platform :string read fplatform;
  end;

procedure Register;
implementation
uses GetArchitecture;

procedure Register;
begin
  RegisterComponents('Smart', [TSystemInfo]);
end;

constructor TSystemInfo.create(AOwner:TComponent);
var
  MyVerInfo     :TOSVersionInfo;    // holds version information
  reg           :TRegIniFile;

begin
  inherited create(AOwner);
  {set the size member of the TOSVersionInfo structure}
  MyVerInfo.dwOSVersionInfoSize := SizeOf(TOSVersionInfo);

  {retrieve the operating system version information}
  GetVersionEx(MyVerInfo);

  {display the operating system version information}
  FMajorVersion:=IntToStr(MyVerInfo.dwMajorVersion);
  FMinorVersion:=IntToStr(MyVerInfo.dwMinorVersion);
  FBuildNumber:=IntToStr(MyVerInfo.dwBuildNumber);
  case MyVerInfo.dwPlatformId of
    VER_PLATFORM_WIN32s        :FPlatform:='Win 32s under Windows 3.1';
    VER_PLATFORM_WIN32_WINDOWS :FPlatform:='Windows 95';
    VER_PLATFORM_WIN32_NT      :FPlatform:='Windows NT';
  end;

   reg := TRegIniFile.create('SOFTWARE\MICROSOFT\MS SETUP (ACME)\');
   fRegUserName:=reg.ReadString('USER INFO',
                                'DefName',
                                'Frank Borland');
   fRegCompanyName:=reg.ReadString('USER INFO',
                                   'DefCompany',
                                   'A Valued Borland Customer');
   reg.free;
   FArchitecture:=GetArchitecture.Architecture;
   FProcessorType:=GetArchitecture.ProcessorType;
   FNumberOfProcessors:=GetArchitecture.NumberOfProcessors;
end;

function TSystemInfo.GetComputernm:string;
var
  ComputerName   :array[0..MAX_COMPUTERNAME_LENGTH+1] of char;  // holds the name
  Size           :Longword;
begin
  {initialize the computer name size variable}
  Size := MAX_COMPUTERNAME_LENGTH+1;

  {retrieve the computer name}
  if GetComputerName(ComputerName, Size) then
    result:=StrPas(Computername)
  else result:='Unknown';
end;

function TSystemInfo.GetUsernm:string;
var
  UserName: PChar;
  Count: longword;
begin
  {retrieve the required size of the user name buffer}
  Count := 0;
  GetUserName(nil,Count);

  {allocate memory for the user name}
  Username := StrAlloc(Count);

  {retrieve the user name}
  if GetUserName(UserName,count) then
    result:= StrPas(UserName)
  else
    result:='Unknown';

  {dispose of allocated memory}
  StrDispose(UserName)
end;

function TSystemInfo.GetSystemDir:string;
Var
  SysDir: array[0..MAX_PATH] of Char;
begin
  {retrieve the system directory}
  GetSystemDirectory(SysDir, MAX_PATH);
  result:= StrPas(SysDir)
end;

function TSystemInfo.GetWindowsDir:string;
var
  WinDir: array[0..MAX_PATH] of char;
begin
  {retrieve the Windows directory}
  GetWindowsDirectory(WinDir, MAX_PATH);
  result:=StrPas(WinDir)
end;

function TSystemInfo.GetTempDir:string;
var
  PathName: array[0..MAX_PATH] of char;
begin
  {retrieve the Temp directory}
  GetTempPath(MAX_PATH, @PathName);

  result:=string(PathName);
end;

function TSystemInfo.GetTotalPhysMemory :longint;
var
  MemInfo : TMemoryStatus;
begin
  MemInfo.dwLength := Sizeof (MemInfo);
  GlobalMemoryStatus (MemInfo);
  result:=MemInfo.dwTotalPhys div 1024;
end;

function TSystemInfo.GetAvailPhysMemory :longint;
var
  MemInfo : TMemoryStatus;
begin
  MemInfo.dwLength := Sizeof (MemInfo);
  GlobalMemoryStatus (MemInfo);
  result:=MemInfo.dwAvailPhys div 1024;
end;

function TSystemInfo.GetTotalSwapMemory :longint;
var
  MemInfo : TMemoryStatus;
begin
  MemInfo.dwLength := Sizeof (MemInfo);
  GlobalMemoryStatus (MemInfo);
  result:=MemInfo.dwTotalPageFile div 1024;
end;

function TSystemInfo.GetAvailSwapMemory :longint;
var
  MemInfo : TMemoryStatus;
begin
  MemInfo.dwLength := Sizeof (MemInfo);
  GlobalMemoryStatus (MemInfo);
  result:=MemInfo.dwAvailPageFile div 1024;
end;

end.
